@@ -35,13 +35,10 @@ my $rootfile = $_[4] ? $file : &make_chroot($file);
 my $FILE;
 if (&is_raw_format_records($rootfile)) {
 	# Convert from raw format first
-	my $compilezone = &has_command("named-compilezone");
-	$compilezone ||
+	&has_command("named-compilezone") ||
 		&error("Zone file $rootfile is in raw format, but the ".
 		       "named-compilezone command is not installed");
-	open($FILE, "-|", $compilezone,
-	     "-f", "raw", "-F", "text", "-o", "-",
-	     $origin, $rootfile);
+	open($FILE, "named-compilezone -f raw -F text -o - $origin $rootfile |");
 	}
 else {
 	# Can read text format records directly
