@@ -132,6 +132,7 @@ if ($out && $dump->{'email'} && &foreign_check("mailboxes")) {
 # Check for any dumps scheduled to run after this one
 foreach $follow (&list_dumps()) {
 	if ($follow->{'follow'} eq $dump->{'id'} && $follow->{'enabled'} == 2) {
-		system("$cron_cmd ".quotemeta($follow->{'id'}));
+		system("$cron_cmd $follow->{'id'}");
 		}
 	}
+
