@@ -10,14 +10,34 @@ $main::mailbox_no_addressbook_button = 1;
 $main::mailbox_no_folder_button = 1;
 
 $main::basic_virtualmin_menu = 1;
+$main::basic_virtualmin_domain = 1;
 $main::nocreate_virtualmin_menu = 1;
 $main::nosingledomain_virtualmin_mode = 1;
 
+our $ui_formcount;
+
 # Global state for wrapper
 # if 0, wrapper isn't on, add one and open it, if 1 close it, if 2+, subtract
 # but don't close
-$WRAPPER_OPEN = 0;
-$COLUMNS_WRAPPER_OPEN = 0;
+$main::WRAPPER_OPEN = 0;
+$main::COLUMNS_WRAPPER_OPEN = 0;
+
+sub theme_ui_print_header
+{
+my ($text, @args) = @_;
+&header(@args);
+print <<EOL;
+<script>
+(function () {
+	const body = document.querySelector('body');
+	try {
+    	body && body.classList.add('$module_name');
+	} catch (e) {}
+})();
+</script>
+EOL
+print &ui_post_header($text);
+}
 
 # theme_ui_post_header([subtext])
 # Returns HTML to appear directly after a standard header() call
@@ -26,8 +46,7 @@ sub theme_ui_post_header
 my ($text) = @_;
 my $rv;
 $rv .= "<div class='ui_post_header'>$text</div>\n" if (defined($text));
-#$rv .= "<div class='section'>\n";
-$rv .= "<p>" if (!defined($text));
+$rv .= "<p></p>" if (!defined($text));
 return $rv;
 }
 
@@ -36,7 +55,7 @@ return $rv;
 sub theme_ui_pre_footer
 {
 my $rv;
-$rv .= "</div><p>\n";
+$rv .= "<p></p>\n";
 return $rv;
 }
 
@@ -47,6 +66,23 @@ sub theme_ui_print_footer
 {
 local @args = @_;
 print &ui_pre_footer();
+if ($ui_formcount) {
+  print <<EOL;
+  <script>
+    (function(){
+        var forms = document.forms || [];
+        for(var i = 0; i < forms.length; i++){
+            for(var j = 0; j < forms[i].length; j++){
+                if(!forms[i][j].readonly != undefined && forms[i][j].type != "hidden" && forms[i][j].disabled != true && forms[i][j].style.display != 'none'){
+                    forms[i][j].focus();
+                    return;
+                }
+            }
+        }
+    })();
+</script>
+EOL
+}
 &footer(@args);
 }
 
@@ -105,7 +141,7 @@ local ($d, $action) = @_;
 print "<script>\n";
 if ($action eq 'create') {
 	# Select the new domain
-	print "top.left.location = '$gconfig{'webprefix'}/left.cgi?dom=$d->{'id'}';\n";
+	print "top.left.location = '@{[&get_webprefix()]}/left.cgi?mode=virtual-server&dom=$d->{'id'}';\n";
 	}
 else {
 	# Just refresh left
@@ -155,7 +191,7 @@ if (window.parent && window.parent.frames[0]) {
 			//	// Need to change value of selector
 			//	serversel.value = '$server->{'id'}';
 			//	}
-			window.parent.frames[0].location = '$gconfig{'webprefix'}/left.cgi?mode=vm2&sid=$server->{'id'}';
+			window.parent.frames[0].location = '@{[&get_webprefix()]}/left.cgi?mode=server-manager&sid=$server->{'id'}';
 			}
 		}
 	}
@@ -179,7 +215,7 @@ if (window.parent && window.parent.frames[0]) {
 		if (domsel && domsel.value != '$d->{'id'}') {
 			// Need to change value
 			// domsel.value = '$d->{'id'}';
-			window.parent.frames[0].location = '$gconfig{'webprefix'}/left.cgi?mode=virtualmin&dom=$d->{'id'}';
+			window.parent.frames[0].location = '@{[&get_webprefix()]}/left.cgi?mode=virtual-server&dom=$d->{'id'}';
 			}
 		}
 	}
@@ -199,7 +235,7 @@ if ($action eq 'create' || $action eq 'delete' || $action eq 'modify') {
 	$ref = 1;
 	}
 else {
-	# Only refesh if showing unread count
+	# Only refresh if showing unread count
 	if (defined(&mailbox::should_show_unread) &&
 	    &mailbox::should_show_unread($folder)) {
 		$ref = 1;
@@ -217,7 +253,7 @@ sub theme_post_change_modules
 print <<EOF;
 <script>
 var url = '' + top.left.location;
-if (url.indexOf('mode=webmin') > 0) {
+if (url.indexOf('mode=modules') > 0) {
     top.left.location = url;
     }
 </script>
@@ -228,8 +264,8 @@ sub theme_prebody
 {
 if ($script_name =~ /session_login.cgi/) {
 	# Generate CSS link
-	print "<link rel='stylesheet' type='text/css' href='$gconfig{'webprefix'}/unauthenticated/gray-reset-fonts-grids-base.css'>\n";
-	print "<link rel='stylesheet' type='text/css' href='$gconfig{'webprefix'}/unauthenticated/gray-virtual-server-style.css'>\n";
+	print "<link rel='stylesheet' type='text/css' href='@{[&get_webprefix()]}/unauthenticated/reset-fonts-grids-base.css'>\n";
+	print "<link rel='stylesheet' type='text/css' href='@{[&get_webprefix()]}/unauthenticated/gray-theme.css'>\n";
 	print "<!--[if IE]>\n";
 	print "<style type=\"text/css\">\n";
 	print "table.formsection, table.ui_table, table.loginform { border-collapse: collapse; }\n";
@@ -244,8 +280,8 @@ if (get_module_name() eq "virtual-server") {
 
 sub theme_prehead
 {
-print "<link rel='stylesheet' type='text/css' href='$gconfig{'webprefix'}/unauthenticated/gray-reset-fonts-grids-base.css'>\n";
-print "<link rel='stylesheet' type='text/css' href='$gconfig{'webprefix'}/unauthenticated/gray-virtual-server-style.css' />\n";
+print "<link rel='stylesheet' type='text/css' href='@{[&get_webprefix()]}/unauthenticated/reset-fonts-grids-base.css'>\n";
+print "<link rel='stylesheet' type='text/css' href='@{[&get_webprefix()]}/unauthenticated/gray-theme.css' />\n";
 print "<!--[if IE]>\n";
 print "<style type=\"text/css\">\n";
 print "table.formsection, table.ui_table, table.loginform { border-collapse: collapse; }\n";
@@ -254,12 +290,7 @@ print "<![endif]-->\n";
 print "<script>\n";
 print "var rowsel = new Array();\n";
 print "</script>\n";
-print "<script type='text/javascript' src='$gconfig{'webprefix'}/unauthenticated/sorttable.js'></script>\n";
-if ($ENV{'HTTP_USER_AGENT'} =~ /Chrome/) {
-	print "<style type=\"text/css\">\n";
-	print "textarea,pre { font-size:120%; }\n";
-	print "</style>\n";
-	}
+print "<script type='text/javascript' src='@{[&get_webprefix()]}/unauthenticated/sorttable.js'></script>\n";
 }
 
 sub theme_popup_prehead
@@ -282,11 +313,11 @@ if (defined($main::ui_table_cols)) {
 my $rv;
 my $colspan = 1;
 
-if (!$WRAPPER_OPEN) {
+if (!$main::WRAPPER_OPEN) {
 	$rv .= "<table class='shrinkwrapper' $tabletags>\n";
 	$rv .= "<tr><td>\n";
 	}
-$WRAPPER_OPEN++;
+$main::WRAPPER_OPEN++;
 $rv .= "<table class='ui_table' $tabletags>\n";
 if (defined($heading) || defined($rightheading)) {
         $rv .= "<thead><tr>";
@@ -312,7 +343,7 @@ return $rv;
 # label and 1+ column value.
 sub theme_ui_table_row
 {
-my ($label, $value, $cols, $tds) = @_;
+my ($label, $value, $cols, $tds, $trs) = @_;
 $cols ||= 1;
 $tds ||= $main::ui_table_default_tds;
 my $rv;
@@ -320,10 +351,21 @@ if ($main::ui_table_pos+$cols+1 > $main::ui_table_cols &&
     $main::ui_table_pos != 0) {
     # If the requested number of cols won't fit in the number
     # remaining, start a new row
+    my $leftover = $main::ui_table_cols - $main::ui_table_pos;
+    $rv .= "<td colspan=$leftover></td>\n";
     $rv .= "</tr>\n";
     $main::ui_table_pos = 0;
     }
-$rv .= "<tr class='ui_form_pair'>\n" if ($main::ui_table_pos%$main::ui_table_cols == 0);
+if (defined($label) &&
+    ($value =~ /id="([^"]+)"/ || $value =~ /id='([^']+)'/ ||
+     $value =~ /id=([^>\s]+)/)) {
+	# Value contains an input with an ID
+	my $id = $1;
+	$label = "<label for=\"".&quote_escape($id)."\">$label</label>";
+	}
+my $trtags_attrs = ref($trs) eq 'ARRAY' && $trs->[0] ? " $trs->[0]" : "";
+my $trtags_class = ref($trs) eq 'ARRAY' && $trs->[1] ? " $trs->[1]" : "";
+$rv .= "<tr class='ui_form_pair$trtags_class'$trtags_attrs>\n" if ($main::ui_table_pos%$main::ui_table_cols == 0);
 $rv .= "<td class='ui_form_label' $tds->[0]><b>$label</b></td>\n" if (defined($label));
 $rv .= "<td class='ui_form_value' colspan=$cols $tds->[1]>$value</td>\n";
 $main::ui_table_pos += $cols+(defined($label) ? 1 : 0);
@@ -334,6 +376,19 @@ if ($main::ui_table_pos%$main::ui_table_cols == 0) {
 return $rv;
 }
 
+sub theme_ui_table_hr
+{
+my $rv;
+if ($main::ui_table_pos) {
+	$rv .= "</tr>\n";
+	$main::ui_table_pos = 0;
+	}
+$rv .= "<tr class='ui_form_pair'>\n";
+$rv .= "<td class='ui_form_label' colspan=$main::ui_table_cols><hr></td>\n";
+$rv .= "</tr>\n";
+return $rv;
+}
+
 # ui_table_end()
 # The end of a table started by ui_table_start
 sub theme_ui_table_end
@@ -354,12 +409,12 @@ else {
   $main::ui_table_default_tds = undef;
   }
 $rv .= "</tbody></table></td></tr></table>\n";
-if ($WRAPPER_OPEN==1) {
+if ($main::WRAPPER_OPEN==1) {
 	#$rv .= "</div>\n";
 	$rv .= "</td></tr>\n";
 	$rv .= "</table>\n";
 	}
-$WRAPPER_OPEN--;
+$main::WRAPPER_OPEN--;
 return $rv;
 }
 
@@ -383,7 +438,7 @@ $rv .= "document.${name}_tabtitles = $tabtitles;\n";
 $rv .= "</script>\n";
 
 # Output the tabs
-my $imgdir = "$gconfig{'webprefix'}/images";
+my $imgdir = "@{[&get_webprefix()]}/images";
 $rv .= &ui_hidden($name, $sel)."\n";
 $rv .= "<table border=0 cellpadding=0 cellspacing=0 class='ui_tabs'>\n";
 $rv .= "<tr><td bgcolor=#ffffff colspan=".(scalar(@$tabs)*2+1).">";
@@ -452,14 +507,14 @@ my ($heads, $width, $noborder, $tdtags, $title) = @_;
 my ($href) = grep { $_ =~ /<a\s+href/i } @$heads;
 my $rv;
 $theme_ui_columns_row_toggle = 0;
-if (!$noborder && !$COLUMNS_WRAPPER_OPEN) {
+if (!$noborder && !$main::COLUMNS_WRAPPER_OPEN) {
 	$rv .= "<table class='wrapper' width="
 	     . ($width ? $width : "100")
 	     . "%>\n";
 	$rv .= "<tr><td>\n";
 	}
 if (!$noborder) {
-	$COLUMNS_WRAPPER_OPEN++;
+	$main::COLUMNS_WRAPPER_OPEN++;
 	}
 my @classes;
 push(@classes, "ui_table") if (!$noborder);
@@ -506,10 +561,10 @@ sub theme_ui_columns_end
 {
 my $rv;
 $rv = "</tbody> </table>\n";
-if ($COLUMNS_WRAPPER_OPEN == 1) { # Last wrapper
+if ($main::COLUMNS_WRAPPER_OPEN == 1) { # Last wrapper
 	$rv .= "</td> </tr> </table>\n";
 	}
-$COLUMNS_WRAPPER_OPEN--;
+$main::COLUMNS_WRAPPER_OPEN--;
 return $rv;
 }
 
@@ -556,6 +611,26 @@ $rv .= "</td></tr></table>\n"; # wrapper
 return $rv;
 }
 
+sub theme_ui_hidden_start
+{
+my ($title, $name, $status) = @_;
+my $rv;
+my $opened = $status ? " open" : "";
+$rv .= "<details class='ui_hidden_start'$opened>";
+$rv .= "<summary>$title</summary>\n";
+return $rv;
+}
+
+=head2 ui_hidden_end(name)
+
+Returns HTML for the end of a hidden section, started by ui_hidden_start.
+
+=cut
+sub theme_ui_hidden_end
+{
+return "</details>\n";
+}
+
 # theme_ui_hidden_table_start(heading, [tabletags], [cols], name, status,
 #                             [&default-tds], [rightheading])
 # A table with a heading and table inside, and which is collapsible
@@ -566,31 +641,17 @@ my $rv;
 if (!$main::ui_hidden_start_donejs++) {
   $rv .= &ui_hidden_javascript();
   }
-my $divid = "hiddendiv_$name";
-my $openerid = "hiddenopener_$name";
-my $defimg = $status ? "open.gif" : "closed.gif";
-my $defclass = $status ? 'opener_shown' : 'opener_hidden';
-my $text = defined($tconfig{'cs_text'}) ? $tconfig{'cs_text'} :
-        defined($gconfig{'cs_text'}) ? $gconfig{'cs_text'} : "000000";
-if (!$WRAPPER_OPEN) { # If we're not already inside of a wrapper, wrap it
-	$rv .= "<table class='shrinkwrapper' $tabletags>\n";
-	$rv .= "<tr><td>\n";
+my $opened = $status ? " open" : "";
+my $header = defined($heading) ? "<span>$heading</span>" : "";
+my $rheader = defined($rightheading) ? "<span class='rightheading'>$rightheading</span>" : "";
+if (!$main::WRAPPER_OPEN) { # If we're not already inside of a wrapper, wrap it
+	$rv .= "<div>\n";
 	}
-$WRAPPER_OPEN++;
+$main::WRAPPER_OPEN++;
 my $colspan = 1;
-$rv .= "<table class='ui_table' $tabletags>\n";
-if (defined($heading) || defined($rightheading)) {
-	$rv .= "<thead><tr>";
-	if (defined($heading)) {
-		$rv .= "<td><a href=\"javascript:hidden_opener('$divid', '$openerid')\" id='$openerid'><img border=0 src='$gconfig{'webprefix'}/images/$defimg'></a> <a href=\"javascript:hidden_opener('$divid', '$openerid')\" class='ui-hidden-table-title'><b>$heading</b></a></td>";
-		}
-        if (defined($rightheading)) {
-                $rv .= "<td align=right>$rightheading</td>";
-                $colspan++;
-                }
-	$rv .= "</tr> </thead>\n";
-	}
-$rv .= "<tbody><tr> <td colspan=$colspan><div class='$defclass' id='$divid'><table width=100%>\n";
+$rv .= "<details class='ui_hidden_table_start'$opened>";
+$rv .= "<summary>$header $rheader</summary>\n";
+$rv .= "<table width=100%>\n";
 $main::ui_table_cols = $cols || 4;
 $main::ui_table_pos = 0;
 $main::ui_table_default_tds = $tds;
@@ -602,14 +663,12 @@ return $rv;
 # ui_hidden_table_start
 sub theme_ui_hidden_table_end
 {
-my ($name) = @_;
-local $rv = "</table></div></td></tr></tbody></table>\n";
-if ( $WRAPPER_OPEN == 1 ) {
-	$WRAPPER_OPEN--;
-	#$rv .= "</div>\n";
-	$rv .= "</td></tr></table>\n";
+local $rv = "</table></details>\n";
+if ( $main::WRAPPER_OPEN == 1 ) {
+	$main::WRAPPER_OPEN--;
+	$rv .= "</div>\n";
 	}
-elsif ($WRAPPER_OPEN) { $WRAPPER_OPEN--; }
+elsif ($main::WRAPPER_OPEN) { $main::WRAPPER_OPEN--; }
 return $rv;
 }
 
@@ -675,15 +734,14 @@ sub theme_ui_checked_columns_row
 $theme_ui_columns_row_toggle = $theme_ui_columns_row_toggle ? '0' : '1';
 local ($cols, $tdtags, $checkname, $checkvalue, $checked, $disabled, $tags) = @_;
 my $rv;
-my $cbid = &quote_escape(quotemeta("${checkname}_${checkvalue}"));
-my $rid = &quote_escape(quotemeta("row_${checkname}_${checkvalue}"));
-my $ridtr = &quote_escape("row_${checkname}_${checkvalue}");
+my $cbid = &quote_escape("${checkname}_${checkvalue}");
+my $rid = &quote_escape("row_${checkname}_${checkvalue}");
 my $mycb = $cb;
 if ($checked) {
 	$mycb =~ s/mainbody/mainsel/g;
 	}
 $mycb =~ s/class='/class='row$theme_ui_columns_row_toggle ui_checked_columns /;
-$rv .= "<tr id=\"$ridtr\" $mycb onMouseOver=\"this.className = document.getElementById('$cbid').checked ? 'mainhighsel' : 'mainhigh'\" onMouseOut=\"this.className = document.getElementById('$cbid').checked ? 'mainsel' : 'mainbody row$theme_ui_columns_row_toggle'\">\n";
+$rv .= "<tr id=\"$rid\" $mycb onMouseOver=\"this.className = document.getElementById('$cbid').checked ? 'mainhighsel' : 'mainhigh'\" onMouseOut=\"this.className = document.getElementById('$cbid').checked ? 'mainsel' : 'mainbody row$theme_ui_columns_row_toggle'\">\n";
 $rv .= "<td class='ui_checked_checkbox' ".$tdtags->[0].">".
        &ui_checkbox($checkname, $checkvalue, undef, $checked, $tags." "."onClick=\"document.getElementById('$rid').className = this.checked ? 'mainhighsel' : 'mainhigh';\"", $disabled).
        "</td>\n";
@@ -708,16 +766,15 @@ sub theme_ui_radio_columns_row
 {
 local ($cols, $tdtags, $checkname, $checkvalue, $checked) = @_;
 my $rv;
-my $cbid = &quote_escape(quotemeta("${checkname}_${checkvalue}"));
-my $rid = &quote_escape(quotemeta("row_${checkname}_${checkvalue}"));
-my $ridtr = &quote_escape("row_${checkname}_${checkvalue}");
+my $cbid = &quote_escape("${checkname}_${checkvalue}");
+my $rid = &quote_escape("row_${checkname}_${checkvalue}");
 my $mycb = $cb;
 if ($checked) {
 	$mycb =~ s/mainbody/mainsel/g;
 	}
 
 $mycb =~ s/class='/class='ui_radio_columns /;
-$rv .= "<tr $mycb id=\"$ridtr\" onMouseOver=\"this.className = document.getElementById('$cbid').checked ? 'mainhighsel' : 'mainhigh'\" onMouseOut=\"this.className = document.getElementById('$cbid').checked ? 'mainsel' : 'mainbody'\">\n";
+$rv .= "<tr $mycb id=\"$rid\" onMouseOver=\"this.className = document.getElementById('$cbid').checked ? 'mainhighsel' : 'mainhigh'\" onMouseOut=\"this.className = document.getElementById('$cbid').checked ? 'mainsel' : 'mainbody'\">\n";
 $rv .= "<td ".$tdtags->[0]." class='ui_radio_radio'>".
        &ui_oneradio($checkname, $checkvalue, undef, $checked, "onClick=\"for(i=0; i<form.$checkname.length; i++) { ff = form.${checkname}[i]; r = document.getElementById('row_'+ff.id); if (r) { r.className = 'mainbody' } } document.getElementById('$rid').className = this.checked ? 'mainhighsel' : 'mainhigh';\"").
        "</td>\n";
@@ -746,11 +803,11 @@ my ($direction, $url, $disabled) = @_;
 my $alt = $direction eq "left" ? '<-' : '->';
 if ($disabled) {
   return "<img alt=\"$alt\" align=\"middle\""
-       . "src=\"$gconfig{'webprefix'}/images/$direction-grey.gif\">\n";
+       . "src=\"@{[&get_webprefix()]}/images/$direction-grey.gif\">\n";
   }
 else {
   return "<a href=\"$url\"><img alt=\"$alt\" align=\"top\""
-       . "src=\"$gconfig{'webprefix'}/images/$direction.gif\"></a>\n";
+       . "src=\"@{[&get_webprefix()]}/images/$direction.gif\"></a>\n";
   }
 }
 
@@ -777,12 +834,12 @@ for($i=0; $i+1<@_; $i+=2) {
 			# Don't bother with Cloudmin menu
 			next;
 			}
-		elsif ($url =~ /(view|edit)_domain.cgi/ &&
-		       get_module_name() eq 'virtual-server' ||
-		       $url =~ /^\/virtual-server\/(view|edit)_domain.cgi/) {
-			# Don't bother with link to domain details
-			next;
-			}
+		#elsif ($url =~ /(view|edit)_domain.cgi/ &&
+		#       get_module_name() eq 'virtual-server' ||
+		#       $url =~ /^\/virtual-server\/(view|edit)_domain.cgi/) {
+		#	# Don't bother with link to domain details
+		#	next;
+		#	}
 		elsif ($url =~ /edit_serv.cgi/ &&
 		       get_module_name() eq 'server-manager' ||
 		       $url =~ /^\/virtual-server\/edit_serv.cgi/) {
@@ -796,7 +853,7 @@ for($i=0; $i+1<@_; $i+=2) {
 		elsif ($url =~ /^\?/ && get_module_name()) {
 			$url = "/".get_module_name()."/$url";
 			}
-		$url = "$gconfig{'webprefix'}$url" if ($url =~ /^\//);
+		$url = "@{[&get_webprefix()]}$url" if ($url =~ /^\//);
 		if ($count++ == 0) {
 			print theme_ui_nav_link("left", $url);
 			}
@@ -808,6 +865,31 @@ for($i=0; $i+1<@_; $i+=2) {
 	}
 print "<br>\n";
 if (!$_[$i]) {
+	my $postbody = $tconfig{'postbody'};
+	if ($postbody) {
+		my $hostname = &get_display_hostname();
+		my $version = &get_webmin_version();
+		my $os_type = $gconfig{'real_os_type'} ||
+			      $gconfig{'os_type'};
+		my $os_version = $gconfig{'real_os_version'} ||
+				 $gconfig{'os_version'};
+		$postbody =~ s/%HOSTNAME%/$hostname/g;
+		$postbody =~ s/%VERSION%/$version/g;
+		$postbody =~ s/%USER%/$remote_user/g;
+		$postbody =~ s/%OS%/$os_type $os_version/g;
+		print "$postbody\n";
+		}
+	if ($tconfig{'postbodyinclude'}) {
+		local $_;
+		open(INC, "$theme_root_directory/$tconfig{'postbodyinclude'}");
+		while(<INC>) {
+			print;
+			}
+		close(INC);
+		}
+	if (defined(&theme_postbody)) {
+		&theme_postbody(@_);
+		}
 	print "</body></html>\n";
 	}
 }
@@ -828,7 +910,7 @@ print "Location: $url\n\n";
 sub theme_ui_hidden_javascript
 {
 my $rv;
-my $imgdir = "$gconfig{'webprefix'}/images";
+my $imgdir = "@{[&get_webprefix()]}/images";
 
 return <<EOF;
 <style>
@@ -867,11 +949,28 @@ for(var i=0; i<tabnames.length; i++) {
 		       '<img src=$imgdir/lc2.gif alt=""></td>'+
 		       '<td class=\\'tabSelected\\' nowrap>'+
 		       '&nbsp;<b>'+title+'</b>&nbsp;</td>'+
-	               '<td valign=top class=\\'tabSelected\\'>'+
+		       '<td valign=top class=\\'tabSelected\\'>'+
 		       '<img src=$imgdir/rc2.gif alt=""></td>'+
 		       '</tr></table>';
     divobj.className = 'opener_shown';
+    try {
+	var nestedForm = divobj.querySelector("form[data-form-nested]");
+	if (nestedForm) {
+		var nestedFormId = nestedForm.getAttribute("data-form-nested"),
+		formSubmitters = document
+			.querySelectorAll(
+				"[data-submit-nested='" + nestedFormId + "']");
+		if (formSubmitters) {
+			formSubmitters.forEach(function(submitter) {
+				submitter.setAttribute(
+					"form", nestedForm.getAttribute('id'));
+			});
+		}
+	}
+    } catch(e) {
+	console.warn('Cannot set the related submitter ID of the nested form : ' + e);
     }
+  }
   else {
     // Non-selected tab
     tabobj.innerHTML = '<table cellpadding=0 cellspacing=0><tr>'+
