@@ -3,6 +3,8 @@
 # Run by edquota to edit some user's quota
 
 $no_acl_check++;
+$0 =~ /^(\S+)\//;
+chdir($1);
 require './quota-lib.pl';
 $u = $ENV{'QUOTA_USER'};
 $fs = $ENV{'QUOTA_FILESYS'};
@@ -12,11 +14,10 @@ $sf = $ENV{'QUOTA_SFILES'};
 $hf = $ENV{'QUOTA_HFILES'};
 $f = $ARGV[0];
 
-open(FILE, $f);
+open(FILE, "<".$f);
 while(<FILE>) { $qdata .= $_; }
 close(FILE);
 $nqdata = &edit_quota_file($qdata, $fs, $sb, $hb, $sf, $hf);
-open(FILE, "> $f");
+open(FILE, ">".$f);
 print FILE $nqdata;
 close(FILE);
-
