@@ -23,7 +23,7 @@ sub open_last_command
 my ($fh, $user, $max) = @_;
 if (&has_command("last")) {
 	my $quser = quotemeta($user);
-	$max = " -n ".quotemeta($max) if ($max);
+	$max = " -n $max" if ($max);
 	open($fh, "(last -F -w$max $quser || last -w$max $quser) |");
 	}
 else {
